==> gorilla-notebook-0.4.0.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.output.latex.js <==
goog.provide('pinkgorilla.output.latex');
goog.require('cljs.core');
goog.require('cljs_uuid_utils.core');
goog.require('reagent.core');
goog.require('pinkgorilla.output.mathjax');
goog.require('pinkgorilla.output.hack');
pinkgorilla.output.latex.output_latex = (function pinkgorilla$output$latex$output_latex(output,seg_id){
var uuid = cljs_uuid_utils.core.uuid_string(cljs_uuid_utils.core.make_random_uuid());
var span_kw = cljs.core.keyword.cljs$core$IFn$_invoke$arity$1(["span#",uuid].join(''));
return reagent.core.create_class(new cljs.core.PersistentArrayMap(null, 3, [new cljs.core.Keyword(null,"component-did-mount","component-did-mount",-1126910518),(function (this$){
return pinkgorilla.output.mathjax.queue_mathjax_rendering(uuid);
}),new cljs.core.Keyword(null,"component-did-update","component-did-update",-1468549173),(function (this$,old_argv){
return null;
}),new cljs.core.Keyword(null,"reagent-render","reagent-render",-985383853),(function (){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [pinkgorilla.output.hack.value_wrap,cljs.core.get.cljs$core$IFn$_invoke$arity$2(output,new cljs.core.Keyword(null,"value","value",305978217)),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [span_kw,new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"class","class",-2030961996),"latex-span",new cljs.core.Keyword(null,"dangerouslySetInnerHTML","dangerouslySetInnerHTML",-554971138),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"__html","__html",674048345),["@@",cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"content","content",15833224).cljs$core$IFn$_invoke$arity$1(output)),"@@"].join('')], null)], null)], null)], null);
})], null));
});

//# sourceMappingURL=pinkgorilla.output.latex.js.map

==> gorilla-notebook-0.4.4.jar: gorilla-repl-client/js/cljs/cljs-runtime/pinkgorilla.output.latex.js <==
goog.provide('pinkgorilla.output.latex');
goog.require('cljs.core');
goog.require('cljs_uuid_utils.core');
goog.require('reagent.core');
goog.require('pinkgorilla.output.mathjax');
goog.require('pinkgorilla.output.hack');
pinkgorilla.output.latex.output_latex = (function pinkgorilla$output$latex$output_latex(output,_){
var uuid = cljs_uuid_utils.core.uuid_string(cljs_uuid_utils.core.make_random_uuid());
var span_kw = cljs.core.keyword.cljs$core$IFn$_invoke$arity$1(["span#",uuid].join(''));
return reagent.core.create_class(new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"component-did-mount","component-did-mount",-1126910518),(function (___$1){
return pinkgorilla.output.mathjax.queue_mathjax_rendering(uuid);
}),new cljs.core.Keyword(null,"reagent-render","reagent-render",-985383853),(function (){
return new cljs.core.PersistentVector(null, 3, 5, cljs.core.PersistentVector.EMPTY_NODE, [pinkgorilla.output.hack.value_wrap,cljs.core.get.cljs$core$IFn$_invoke$arity$2(output,new cljs.core.Keyword(null,"value","value",305978217)),new cljs.core.PersistentVector(null, 2, 5, cljs.core.PersistentVector.EMPTY_NODE, [span_kw,new cljs.core.PersistentArrayMap(null, 2, [new cljs.core.Keyword(null,"class","class",-2030961996),"latex-span",new cljs.core.Keyword(null,"dangerouslySetInnerHTML","dangerouslySetInnerHTML",-554971138),new cljs.core.PersistentArrayMap(null, 1, [new cljs.core.Keyword(null,"__html","__html",674048345),["@@",cljs.core.str.cljs$core$IFn$_invoke$arity$1(new cljs.core.Keyword(null,"content","content",15833224).cljs$core$IFn$_invoke$arity$1(output)),"@@"].join('')], null)], null)], null)], null);
})], null));
});

//# sourceMappingURL=pinkgorilla.output.latex.js.map
